@@ -1,25 +1,27 @@
 
 import sys
 import os
-import pickle
+import json
 import multiprocessing
-import ConfigParser as configparser
 import random
 import subprocess
+try:
+    import ConfigParser as configparser
+except ImportError:
+    import configparser as configparser
 
 from PyQt4.QtCore import *
 from PyQt4.QtGui import *
 
 
-from qtcustom import *
+from .qtcustom import *
 import pytrailer as amt
-from downloader import TrailerDownloader, DownloadStatus
+from .downloader import TrailerDownloader, DownloadStatus
 
 categories = [('Just added', '/trailers/home/feeds/just_added.json'),
               ('Exclusive', '/trailers/home/feeds/exclusive.json'),
               ('Only HD', '/trailers/home/feeds/just_hd.json'),
-              ('Most popular', '/trailers/home/feeds/most_pop.json'),
-              ('Search', '/trailers/home/scripts/quickfind.php?callback=searchCallback&q=')]
+              ('Most popular', '/trailers/home/feeds/most_pop.json')]
 
 
 class PyTrailerWidget(QMainWindow):
@@ -28,9 +30,10 @@ class PyTrailerWidget(QMainWindow):
     def __init__(self, *args):
         QMainWindow.__init__(self, *args)
         self.config = configparser.SafeConfigParser({'downloadDir':'/tmp',
-                                       'filters':pickle.dumps([]),
+                                       'filters':json.dumps([y for x, y in PyTrailerSettings.filters]),
                                        'readAhead':'4',
-                                       'parallelDownload':'2'})
+                                       'parallelDownload':'2',
+                                       'player':'mplayer -user-agent %%a %%u'})
         readAhead = int(self.config.get("DEFAULT","readAhead"))
         self.config.read(self.configPath)
         self.movieDict = {}
@@ -167,7 +170,12 @@ class PyTrailerWidget(QMainWindow):
         self.movieList = amt.getMoviesFromJSON(url)
         for i in range(len(self.movieList)):
             self.readAheadTaskQueue.put((i, self.movieList[i], self.loadID))
-        filters = pickle.loads(self.config.get("DEFAULT",'filters'))
+        try:
+            filters = json.loads(self.config.get("DEFAULT","filters"))
+        except ValueError:
+            # we have old config load old style pickle
+            import pickle
+            filters = pickle.loads(self.config.get("DEFAULT","filters"))
 
         for movie in self.movieList:
             w=MovieItemWidget(movie, filters, self.scrollArea)
@@ -178,7 +186,7 @@ class PyTrailerWidget(QMainWindow):
             self.mainArea.addWidget(w)
 
     def saveConfig(self):
-        with open(self.configPath, 'wb') as configfile:
+        with open(self.configPath, 'w') as configfile:
             self.config.write(configfile)
 
     def closeEvent(self, closeEvent):
@@ -198,8 +206,7 @@ class PyTrailerWidget(QMainWindow):
             oldMovie.poster = updatedMovie.poster
             oldMovie.trailerLinks = updatedMovie.trailerLinks
             oldMovie.description = updatedMovie.description
-            oldMovie.cached = True
-            if self.movieDict.has_key(oldMovie.title):
+            if oldMovie.title in self.movieDict:
                 w = self.movieDict[oldMovie.title]
                 if w is not None:
                     w.refresh()
@@ -207,7 +214,7 @@ class PyTrailerWidget(QMainWindow):
 
     def refreshDownloadStatus(self):
 
-        for i in self.trailerDownloadDict.keys():
+        for i in list(self.trailerDownloadDict.keys()):
             item = self.trailerDownloadDict[i]
             trailerName = item.url.split('/')[-1]
             statusText = None
@@ -231,7 +238,7 @@ class PyTrailerWidget(QMainWindow):
                 self.statusView.addTopLevelItem(match)
 
 
-        if len(self.trailerDownloadDict.keys()) and not self.statusView.isVisible():
+        if len(list(self.trailerDownloadDict.keys())) and not self.statusView.isVisible():
             self.statusView.setVisible(True)
 
     def downloadTrailer(self, url):
@@ -240,10 +247,14 @@ class PyTrailerWidget(QMainWindow):
         self.trailerDownloadDict[str(url)] = DownloadStatus(str(url),
                            DownloadStatus.WAITING)
     def viewTrailer(self, url):
-        command = ['mplayer','-user-agent',
-                   'QuickTime/7.6.2 (qtver=7.6.2;os=Windows NT5.1 Service Pack 3)',
-                   url]
-        subprocess.Popen(command)
+        player = self.config.get("DEFAULT","player").split(' ')
+        for i in range(len(player)):
+            if player[i] == '%a':
+                player[i] = 'QuickTime/7.6.2 (qtver=7.6.2;os=Windows NT5.1 Service Pack 3)'
+            elif player[i] == '%u':
+                player[i] = url
+
+        subprocess.Popen(player)
 
 
 def movieReadAhead(taskQueue, doneQueue):
